changeset 14906:f3a5036cc13c

javadoc fixes javadoc has become stricter in jdk8
author Bernhard Urban <bernhard.urban@jku.at>
date Mon, 31 Mar 2014 20:51:09 +0200
parents b7afc71535d3
children 7683ad455d81
files graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/BytecodeFrame.java graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/DebugInfo.java graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/MemoryBarriers.java graal/com.oracle.graal.api.meta.jdk8.test/src/com/oracle/graal/api/meta/jdk8/test/TestResolvedJavaMethodJDK8.java graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractJavaProfile.java graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractProfiledItem.java graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntLookupSwitchTest.java graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntTableSwitchTest.java graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/StringSwitchTest.java graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/MethodFilter.java graal/com.oracle.graal.debug/src/com/oracle/graal/debug/Debug.java graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotRegisterConfig.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/CompileTheWorld.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotBackend.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotVMConfig.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/debug/BenchmarkCounters.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotInstalledCode.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotMethodDataAccessor.java graal/com.oracle.graal.java/src/com/oracle/graal/java/BciBlockMapping.java graal/com.oracle.graal.java/src/com/oracle/graal/java/GraphBuilderPhase.java graal/com.oracle.graal.jtt/src/com/oracle/graal/jtt/hotspot/Test6196102.java graal/com.oracle.graal.lir.amd64/src/com/oracle/graal/lir/amd64/AMD64FrameMap.java graal/com.oracle.graal.lir.sparc/src/com/oracle/graal/lir/sparc/SPARCFrameMap.java graal/com.oracle.graal.lir/src/com/oracle/graal/lir/EdgeMoveOptimizer.java graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/ConstantNode.java graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/FrameState.java graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/BinaryNode.java graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/NormalizeCompareNode.java graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/extended/BranchProbabilityNode.java graal/com.oracle.graal.options/src/com/oracle/graal/options/OptionValue.java graal/com.oracle.graal.phases.common/src/com/oracle/graal/phases/common/InliningUtil.java graal/com.oracle.graal.phases/src/com/oracle/graal/phases/schedule/SchedulePhase.java graal/com.oracle.graal.printer/src/com/oracle/graal/printer/HexCodeFile.java graal/com.oracle.graal.replacements/src/com/oracle/graal/replacements/SnippetTemplate.java graal/com.oracle.truffle.api.dsl.test/src/com/oracle/truffle/api/dsl/test/package-info.java graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeCheck.java graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeSystem.java graal/com.oracle.truffle.api.test/src/com/oracle/truffle/api/test/package-info.java graal/com.oracle.truffle.api/src/com/oracle/truffle/api/CompilerDirectives.java graal/com.oracle.truffle.api/src/com/oracle/truffle/api/debug/DefaultDebugManager.java graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/SLMain.java graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/SLExpressionNode.java graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLWhileNode.java
diffstat 44 files changed, 194 insertions(+), 198 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/BytecodeFrame.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/BytecodeFrame.java	Mon Mar 31 20:51:09 2014 +0200
@@ -39,7 +39,7 @@
      * An array of values representing how to reconstruct the state of the Java frame. This is array
      * is partitioned as follows:
      * <p>
-     * <table border="1" cellpadding="5" frame="void", rules="all">
+     * <table summary="" border="1" cellpadding="5" frame="void" rules="all">
      * <tr>
      * <th>Start index (inclusive)</th>
      * <th>End index (exclusive)</th>
@@ -95,7 +95,7 @@
 
     /**
      * Creates a new frame object.
-     * 
+     *
      * @param caller the caller frame (which may be {@code null})
      * @param method the method
      * @param bci a BCI within the method
@@ -138,7 +138,7 @@
 
     /**
      * Gets the value representing the specified local variable.
-     * 
+     *
      * @param i the local variable index
      * @return the value that can be used to reconstruct the local's current value
      */
@@ -148,7 +148,7 @@
 
     /**
      * Gets the value representing the specified stack slot.
-     * 
+     *
      * @param i the stack index
      * @return the value that can be used to reconstruct the stack slot's current value
      */
@@ -158,7 +158,7 @@
 
     /**
      * Gets the value representing the specified lock.
-     * 
+     *
      * @param i the lock index
      * @return the value that can be used to reconstruct the lock's current value
      */
@@ -168,7 +168,7 @@
 
     /**
      * Gets the caller of this frame.
-     * 
+     *
      * @return {@code null} if this frame has no caller
      */
     public BytecodeFrame caller() {
--- a/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/DebugInfo.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/DebugInfo.java	Mon Mar 31 20:51:09 2014 +0200
@@ -32,6 +32,7 @@
  * their values can be read</li>
  * <li>a map from the registers (in the caller's frame) to the slots where they are saved in the
  * current frame</li>
+ * </ul>
  */
 public class DebugInfo {
 
@@ -41,7 +42,7 @@
 
     /**
      * Creates a new {@link DebugInfo} from the given values.
-     * 
+     *
      * @param codePos the {@linkplain BytecodePosition code position} or {@linkplain BytecodeFrame
      *            frame} info
      * @param referenceMap the reference map
@@ -60,7 +61,7 @@
 
     /**
      * Gets the deoptimization information for each inlined frame (if available).
-     * 
+     *
      * @return {@code null} if no frame de-opt info is {@linkplain #hasFrame() available}
      */
     public BytecodeFrame frame() {
--- a/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/MemoryBarriers.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.code/src/com/oracle/graal/api/code/MemoryBarriers.java	Mon Mar 31 20:51:09 2014 +0200
@@ -24,7 +24,7 @@
 
 /**
  * Constants and intrinsic definition for memory barriers.
- * 
+ *
  * The documentation for each constant is taken from Doug Lea's <a
  * href="http://gee.cs.oswego.edu/dl/jmm/cookbook.html">The JSR-133 Cookbook for Compiler
  * Writers</a>.
@@ -32,17 +32,17 @@
  * The {@code JMM_*} constants capture the memory barriers necessary to implement the Java Memory
  * Model with respect to volatile field accesses. Their values are explained by this comment from
  * templateTable_i486.cpp in the HotSpot source code:
- * 
+ *
  * <pre>
  * Volatile variables demand their effects be made known to all CPU's in
- * order.  Store buffers on most chips allow reads & writes to reorder; the
+ * order.  Store buffers on most chips allow reads &amp; writes to reorder; the
  * JMM's ReadAfterWrite.java test fails in -Xint mode without some kind of
  * memory barrier (i.e., it's not sufficient that the interpreter does not
  * reorder volatile references, the hardware also must not reorder them).
  * 
  * According to the new Java Memory Model (JMM):
  * (1) All volatiles are serialized wrt to each other.
- * ALSO reads & writes act as acquire & release, so:
+ * ALSO reads &amp; writes act as acquire &amp; release, so:
  * (2) A read cannot let unrelated NON-volatile memory refs that happen after
  * the read float up to before the read.  It's OK for non-volatile memory refs
  * that happen before the volatile read to float down below it.
--- a/graal/com.oracle.graal.api.meta.jdk8.test/src/com/oracle/graal/api/meta/jdk8/test/TestResolvedJavaMethodJDK8.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.meta.jdk8.test/src/com/oracle/graal/api/meta/jdk8/test/TestResolvedJavaMethodJDK8.java	Mon Mar 31 20:51:09 2014 +0200
@@ -33,7 +33,7 @@
 import com.oracle.graal.api.meta.test.*;
 
 /**
- * Tests for {@link ResolvedJavaMethod} that require JDK >= 8.
+ * Tests for {@link ResolvedJavaMethod} that require JDK &ge; 8.
  */
 public class TestResolvedJavaMethodJDK8 extends MethodUniverse {
 
--- a/graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractJavaProfile.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractJavaProfile.java	Mon Mar 31 20:51:09 2014 +0200
@@ -29,7 +29,7 @@
  * BCI. The precision of the supplied values may vary, but a runtime that provides this information
  * should be aware that it will be used to guide performance-critical decisions like speculative
  * inlining, etc.
- * 
+ *
  * @param <T> a subclass of AbstractProfiledItem
  * @param <U> the class of the items that are profiled at the specific BCI and for which
  *            probabilities are stored. E.g., a ResolvedJavaType or a ResolvedJavaMethod.
@@ -64,8 +64,8 @@
     /**
      * Returns the estimated probability of all types that could not be recorded due to profiling
      * limitations.
-     * 
-     * @return double value >= 0.0 and <= 1.0
+     *
+     * @return double value &ge; 0.0 and &le; 1.0
      */
     public double getNotRecordedProbability() {
         return notRecordedProbability;
@@ -77,7 +77,7 @@
 
     /**
      * Searches for an entry of a given resolved Java type.
-     * 
+     *
      * @param type the type for which an entry should be searched
      * @return the entry or null if no entry for this type can be found
      */
--- a/graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractProfiledItem.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.api.meta/src/com/oracle/graal/api/meta/AbstractProfiledItem.java	Mon Mar 31 20:51:09 2014 +0200
@@ -48,8 +48,8 @@
 
     /**
      * Returns the estimated probability of {@link #getItem()}.
-     * 
-     * @return double value >= 0.0 and <= 1.0
+     *
+     * @return double value &ge; 0.0 and &le; 1.0
      */
     public double getProbability() {
         return probability;
--- a/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntLookupSwitchTest.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntLookupSwitchTest.java	Mon Mar 31 20:51:09 2014 +0200
@@ -29,21 +29,21 @@
 /**
  * Tests a switch statement with integer keys. This test exercises the LOOKUPSWITCH Java bytecode
  * instruction.
- * 
+ *
  * The HSAIL code generated for this example is a series of cascading compare and branch
  * instructions for each case of the switch.
- * 
+ *
  * These HSAIL instructions have the following form:
- * 
- * 
+ *
+ *
  * //Check whether the key matches the key constant of the case. Store the result of the compare (0
  * or 1) in the control register c0.
- * 
- * cmp_eq $c0 <source register>, <key constant for case statement>
- * 
+ *
+ * cmp_eq $c0 &lt;source register&gt;, &lt;key constant for case statement&gt;
+ *
  * //Branch to the corresponding label of that case if there's a match.
- * 
- * cbr $c0 <branch target for that case>
+ *
+ * cbr $c0 &lt;branch target for that case&gt;
  */
 public class IntLookupSwitchTest extends GraalKernelTester {
 
@@ -54,12 +54,12 @@
     /**
      * The static "kernel" method we will be testing. This method writes to an output array based on
      * switching on an element of an input array. By convention the gid is the last parameter.
-     * 
+     *
      * Note: Because the key constants used in the cases of the switch are sparsely distributed, the
      * Java source compiler compiles this example into the LOOKUPSWITCH bytecode instruction. So
      * this is really a test to see whether the HSAIL backend is appropriately handling the
      * LOOKUPSWITCH bytecode.
-     * 
+     *
      * @param out the output array
      * @param ina the input array
      * @param gid the parameter used to index into the input and output arrays
@@ -102,7 +102,7 @@
 
     /**
      * Initializes the input and output arrays passed to the run routine.
-     * 
+     *
      * @param in the input array
      */
     void setupArrays(int[] in) {
--- a/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntTableSwitchTest.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/IntTableSwitchTest.java	Mon Mar 31 20:51:09 2014 +0200
@@ -29,21 +29,21 @@
 /**
  * Tests a switch statement with integer keys. This test exercises the TABLESWITCH Java bytecode
  * instruction.
- * 
+ *
  * The HSAIL code generated for this example is a series of cascading compare and branch
  * instructions for each case of the switch.
- * 
+ *
  * These instruction have the following form:
- * 
- * 
+ *
+ *
  * //Check whether the key matches the key constant of the case. Store the result of the compare (0
  * or 1) in the control register c0.
- * 
- * cmp_eq $c0 <source register>, <key constant for case statement>
- * 
+ *
+ * cmp_eq $c0 &lt;source register&gt;, &lt;key constant for case statement&gt;
+ *
  * //Branch to the corresponding label of that case if there's a match.
- * 
- * cbr $c0 <branch target for that case>
+ *
+ * cbr $c0 &lt;branch target for that case&gt;
  */
 public class IntTableSwitchTest extends GraalKernelTester {
 
@@ -54,12 +54,12 @@
     /**
      * The static "kernel" method we will be testing. This method writes to an output array based on
      * switching on an element of an input array.
-     * 
+     *
      * Note: Because the key constants used in the cases of the switch are in consecutive order, the
      * Java source compiler compiles this example into the TABLESWITCH bytecode instruction. So this
      * is really a test to see whether the HSAIL backend is appropriately handling the TABLESWITCH
      * bytecode.
-     * 
+     *
      * @param out the output array
      * @param ina the input array
      * @param gid the parameter used to index into the input and output arrays
@@ -115,7 +115,7 @@
 
     /**
      * Initializes the input and output arrays passed to the run routine.
-     * 
+     *
      * @param in the input array
      */
     void setupArrays(int[] in) {
--- a/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/StringSwitchTest.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.compiler.hsail.test/src/com/oracle/graal/compiler/hsail/test/StringSwitchTest.java	Mon Mar 31 20:51:09 2014 +0200
@@ -30,24 +30,24 @@
 
 /**
  * Tests switch statement with String literal keys.
- * 
+ *
  * Note: In Java bytecode, this example reduces to a LOOKUPSWITCH over int keys because the Java
  * source compiler generates a call to String.hashcode( ) to convert to int values.
- * 
+ *
  * The HSAIL code generated for this example is a series of cascading compare and branch
  * instructions for each case of the switch.
- * 
+ *
  * These instruction have the following form:
- * 
- * 
+ *
+ *
  * //Check whether the key matches the key constant of the case. Store the result of the compare (0
  * or 1) in the control register c0.
- * 
- * cmp_eq $c0 <source register>, <key constant for case statement>
- * 
+ *
+ * cmp_eq $c0 &lt;source register&gt;, &lt;key constant for case statement&gt;
+ *
  * //Branch to the corresponding label of that case if there's a match.
- * 
- * cbr $c0 <branch target for that case>
+ *
+ * cbr $c0 &lt;branch target for that case&gt;
  */
 public class StringSwitchTest extends GraalKernelTester {
 
@@ -62,7 +62,7 @@
     /**
      * The static "kernel" method we will be testing. This method performs a switch statement over a
      * String literal key.
-     * 
+     *
      * @param out the output array
      * @param ina the input array of String literal keys
      * @param gid the parameter used to index into the input and output arrays
@@ -133,7 +133,7 @@
 
     /**
      * Initializes the input and output arrays passed to the run routine.
-     * 
+     *
      * @param in the input array
      */
     void setupArrays(String[] in) {
--- a/graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/MethodFilter.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/MethodFilter.java	Mon Mar 31 20:51:09 2014 +0200
@@ -30,63 +30,62 @@
 /**
  * This class implements a method filter that can filter based on class name, method name and
  * parameters. The syntax for the source pattern that is passed to the constructor is as follows:
- * 
+ *
  * <pre>
  * SourcePatterns = SourcePattern ["," SourcePatterns] .
  * SourcePattern = [ Class "." ] method [ "(" [ Parameter { ";" Parameter } ] ")" ] .
  * Parameter = Class | "int" | "long" | "float" | "double" | "short" | "char" | "boolean" .
  * Class = { package "." } class .
  * </pre>
- * 
- * 
+ *
+ *
  * Glob pattern matching (*, ?) is allowed in all parts of the source pattern. Examples for valid
  * filters are:
- * 
+ *
  * <ul>
  * <li>
- * 
+ *
  * <pre>
  * visit(Argument;BlockScope)
  * </pre>
- * 
+ *
  * Matches all methods named "visit", with the first parameter of type "Argument", and the second
  * parameter of type "BlockScope". The packages of the parameter types are irrelevant.</li>
  * <li>
- * 
+ *
  * <pre>
  * arraycopy(Object;;;;)
  * </pre>
- * 
+ *
  * Matches all methods named "arraycopy", with the first parameter of type "Object", and four more
  * parameters of any type. The packages of the parameter types are irrelevant.</li>
  * <li>
- * 
+ *
  * <pre>
  * com.oracle.graal.compiler.graph.PostOrderNodeIterator.*
  * </pre>
- * 
+ *
  * Matches all methods in the class "com.oracle.graal.compiler.graph.PostOrderNodeIterator".</li>
  * <li>
- * 
+ *
  * <pre>
  * *
  * </pre>
- * 
+ *
  * Matches all methods in all classes</li>
  * <li>
- * 
+ *
  * <pre>
  * com.oracle.graal.compiler.graph.*.visit
  * </pre>
- * 
- * Matches all methods named "visit" in classes in the package
- * "com.oracle.graal.compiler.graph".</pre>
+ *
+ * Matches all methods named "visit" in classes in the package "com.oracle.graal.compiler.graph".
  * <li>
- * 
+ *
  * <pre>
  * arraycopy,toString
  * </pre>
- * 
+ *
  * Matches all methods named "arraycopy" or "toString", meaning that ',' acts as an <i>or</i>
  * operator.</li>
  * </ul>
--- a/graal/com.oracle.graal.debug/src/com/oracle/graal/debug/Debug.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.debug/src/com/oracle/graal/debug/Debug.java	Mon Mar 31 20:51:09 2014 +0200
@@ -142,8 +142,8 @@
 
     /**
      * Represents a debug scope entered by {@link Debug#scope(Object)} or
-     * {@link Debug#sandbox(String, DebugConfig, Object...)}. Leaving the scope is achieved via
-     * {@link #close()}.
+     * {@link Debug#sandbox(CharSequence, DebugConfig, Object...)}. Leaving the scope is achieved
+     * via {@link #close()}.
      */
     public interface Scope extends AutoCloseable {
         void close();
@@ -276,10 +276,10 @@
      * Handles an exception in the context of the debug scope just exited. The just exited scope
      * must have the current scope as its parent which will be the case if the try-with-resource
      * pattern recommended by {@link #scope(Object)} and
-     * {@link #sandbox(String, DebugConfig, Object...)} is used
+     * {@link #sandbox(CharSequence, DebugConfig, Object...)} is used
      *
      * @see #scope(Object)
-     * @see #sandbox(String, DebugConfig, Object...)
+     * @see #sandbox(CharSequence, DebugConfig, Object...)
      */
     public static RuntimeException handle(Throwable exception) {
         if (ENABLED) {
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/CompileTheWorld.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/CompileTheWorld.java	Mon Mar 31 20:51:09 2014 +0200
@@ -22,7 +22,6 @@
  */
 package com.oracle.graal.hotspot;
 
-import static com.oracle.graal.hotspot.CompileTheWorld.Options.*;
 import static com.oracle.graal.hotspot.HotSpotGraalRuntime.*;
 import static com.oracle.graal.nodes.StructuredGraph.*;
 import static com.oracle.graal.phases.GraalOptions.*;
@@ -91,7 +90,7 @@
      * A mechanism for overriding Graal options that affect compilation. A {@link Config} object
      * should be used in a try-with-resources statement to ensure overriding of options is scoped
      * properly. For example:
-     * 
+     *
      * <pre>
      *     Config config = ...;
      *     try (AutoCloseable s = config == null ? null : config.apply()) {
@@ -105,7 +104,7 @@
 
         /**
          * Creates a {@link Config} object by parsing a set of space separated override options.
-         * 
+         *
          * @param options a space separated set of option value settings with each option setting in
          *            a format compatible with
          *            {@link HotSpotOptions#parseOption(String, OptionConsumer)}. Ignored if null.
@@ -146,13 +145,13 @@
     // Some runtime instances we need.
     private final HotSpotGraalRuntime runtime = runtime();
 
-    /** List of Zip/Jar files to compile (see {@link #CompileTheWorldClasspath}. */
+    /** List of Zip/Jar files to compile (see {@link Options#CompileTheWorldClasspath}). */
     private final String files;
 
-    /** Class index to start compilation at (see {@link #CompileTheWorldStartAt}. */
+    /** Class index to start compilation at (see {@link Options#CompileTheWorldStartAt}). */
     private final int startAt;
 
-    /** Class index to stop compilation at (see {@link #CompileTheWorldStopAt}. */
+    /** Class index to stop compilation at (see {@link Options#CompileTheWorldStopAt}). */
     private final int stopAt;
 
     // Counters
@@ -165,7 +164,7 @@
 
     /**
      * Creates a compile-the-world instance.
-     * 
+     *
      * @param files {@link File#pathSeparator} separated list of Zip/Jar files to compile
      * @param startAt index of the class file to start compilation at
      * @param stopAt index of the class file to stop compilation at
@@ -187,9 +186,9 @@
 
     /**
      * Compiles all methods in all classes in the Zip/Jar archive files in
-     * {@link #CompileTheWorldClasspath}. If {@link #CompileTheWorldClasspath} contains the magic
-     * token {@link #SUN_BOOT_CLASS_PATH} passed up from HotSpot we take the files from the boot
-     * class path.
+     * {@link Options#CompileTheWorldClasspath}. If {@link Options#CompileTheWorldClasspath}
+     * contains the magic token {@link #SUN_BOOT_CLASS_PATH} passed up from HotSpot we take the
+     * files from the boot class path.
      */
     public void compile() throws Throwable {
         if (SUN_BOOT_CLASS_PATH.equals(files)) {
@@ -229,7 +228,7 @@
 
     /**
      * Compiles all methods in all classes in the Zip/Jar files passed.
-     * 
+     *
      * @param fileList {@link File#pathSeparator} separated list of Zip/Jar files to compile
      * @throws Throwable
      */
@@ -364,7 +363,7 @@
 
     /**
      * Determines if a method should be compiled (Cf. CompilationPolicy::can_be_compiled).
-     * 
+     *
      * @return true if it can be compiled, false otherwise
      */
     private boolean canBeCompiled(HotSpotResolvedJavaMethod javaMethod, int modifiers) {
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotBackend.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotBackend.java	Mon Mar 31 20:51:09 2014 +0200
@@ -44,7 +44,7 @@
 public abstract class HotSpotBackend extends Backend {
 
     /**
-     * Descriptor for SharedRuntime::deopt_blob()->uncommon_trap().
+     * Descriptor for SharedRuntime::deopt_blob()-&gt;uncommon_trap().
      */
     public static final ForeignCallDescriptor UNCOMMON_TRAP = new ForeignCallDescriptor("deoptimize", void.class);
 
@@ -56,7 +56,7 @@
     public static final ForeignCallDescriptor EXCEPTION_HANDLER = new ForeignCallDescriptor("exceptionHandler", void.class, Object.class, Word.class);
 
     /**
-     * Descriptor for SharedRuntime::deopt_blob()->unpack().
+     * Descriptor for SharedRuntime::deopt_blob()-&gt;unpack().
      */
     public static final ForeignCallDescriptor DEOPT_HANDLER = new ForeignCallDescriptor("deoptHandler", void.class);
 
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotVMConfig.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/HotSpotVMConfig.java	Mon Mar 31 20:51:09 2014 +0200
@@ -1320,14 +1320,14 @@
     @HotSpotVMField(name = "VirtualSpace::_high_boundary", type = "char*", get = HotSpotVMField.Type.OFFSET) @Stable private int virtualSpaceHighBoundaryOffset;
 
     /**
-     * @return CodeCache::_heap->_memory._low_boundary
+     * @return CodeCache::_heap-&gt;_memory._low_boundary
      */
     public long codeCacheLowBoundary() {
         return unsafe.getAddress(codeCacheHeap + codeHeapMemoryOffset + virtualSpaceLowBoundaryOffset);
     }
 
     /**
-     * @return CodeCache::_heap->_memory._high_boundary
+     * @return CodeCache::_heap-&gt;_memory._high_boundary
      */
     public long codeCacheHighBoundary() {
         return unsafe.getAddress(codeCacheHeap + codeHeapMemoryOffset + virtualSpaceHighBoundaryOffset);
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/debug/BenchmarkCounters.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/debug/BenchmarkCounters.java	Mon Mar 31 20:51:09 2014 +0200
@@ -49,7 +49,8 @@
 /**
  * This class contains infrastructure to maintain counters based on {@link DynamicCounterNode}s. The
  * infrastructure is enabled by specifying either the GenericDynamicCounters or
- * BenchmarkDynamicCounters option.<br/>
+ * BenchmarkDynamicCounters option.
+ * <p>
  *
  * The counters are kept in a special area allocated for each native JavaThread object, and the
  * number of counters is configured using {@code -XX:GraalCounterSize=value}.
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotInstalledCode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotInstalledCode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -71,7 +71,7 @@
     }
 
     /**
-     * @returns a copy of this code blob if it is {@linkplain #isValid() valid}, null otherwise.
+     * @return a copy of this code blob if it is {@linkplain #isValid() valid}, null otherwise.
      */
     public byte[] getBlob() {
         if (!isValid()) {
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotMethodDataAccessor.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/meta/HotSpotMethodDataAccessor.java	Mon Mar 31 20:51:09 2014 +0200
@@ -89,14 +89,14 @@
     /**
      * Returns the BCI stored in the LayoutData header.
      * 
-     * @return An integer >= 0 and <= Short.MAX_VALUE, or -1 if not supported.
+     * @return An integer &ge; 0 and &le; Short.MAX_VALUE, or -1 if not supported.
      */
     int getBCI(HotSpotMethodData data, int position);
 
     /**
      * Computes the size for the specific data at the given position.
      * 
-     * @return An integer > 0.
+     * @return An integer &gt; 0.
      */
     int getSize(HotSpotMethodData data, int position);
 
--- a/graal/com.oracle.graal.java/src/com/oracle/graal/java/BciBlockMapping.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.java/src/com/oracle/graal/java/BciBlockMapping.java	Mon Mar 31 20:51:09 2014 +0200
@@ -206,7 +206,7 @@
 
     /**
      * Creates a new BlockMap instance from bytecode of the given method .
-     * 
+     *
      * @param method the compiler interface method containing the code
      */
     private BciBlockMapping(ResolvedJavaMethod method) {
@@ -768,8 +768,8 @@
     }
 
     /**
-     * Encapsulates the liveness calculation, so that subclasses for locals <= 64 and locals > 64
-     * can be implemented.
+     * Encapsulates the liveness calculation, so that subclasses for locals &le; 64 and locals &gt;
+     * 64 can be implemented.
      */
     public abstract class LocalLiveness {
 
--- a/graal/com.oracle.graal.java/src/com/oracle/graal/java/GraphBuilderPhase.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.java/src/com/oracle/graal/java/GraphBuilderPhase.java	Mon Mar 31 20:51:09 2014 +0200
@@ -1377,7 +1377,7 @@
              *
              * @param instr The last instruction (= fixed node) which was added.
              * @param state The current frame state.
-             * @Returns Returns the (new) last instruction.
+             * @return Returns the (new) last instruction.
              */
             protected FixedWithNextNode finishInstruction(FixedWithNextNode instr, HIRFrameStateBuilder state) {
                 return instr;
--- a/graal/com.oracle.graal.jtt/src/com/oracle/graal/jtt/hotspot/Test6196102.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.jtt/src/com/oracle/graal/jtt/hotspot/Test6196102.java	Mon Mar 31 20:51:09 2014 +0200
@@ -26,13 +26,11 @@
 import com.oracle.graal.jtt.*;
 
 /**
- * @LongTest
  * @bug 6196102
- * @summary Integer seems to be greater than Integer.MAX_VALUE
- * 
+ * @summary Integer seems to be greater than {@link Integer#MAX_VALUE}.
+ *
  * @run main Test6196102
  */
-// @formatter:off
 public class Test6196102 extends JTTTest {
 
     public static String test() {
--- a/graal/com.oracle.graal.lir.amd64/src/com/oracle/graal/lir/amd64/AMD64FrameMap.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.lir.amd64/src/com/oracle/graal/lir/amd64/AMD64FrameMap.java	Mon Mar 31 20:51:09 2014 +0200
@@ -28,12 +28,12 @@
 
 /**
  * AMD64 specific frame map.
- * 
+ *
  * This is the format of an AMD64 stack frame:
- * 
+ *
  * <pre>
  *   Base       Contents
- * 
+ *
  *            :                                :  -----
  *   caller   | incoming overflow argument n   |    ^
  *   frame    :     ...                        :    | positive
@@ -54,10 +54,10 @@
  *            | outgoing overflow argument n   |    ^            |      |
  *            :     ...                        :    | positive   |      |
  *            | outgoing overflow argument 0   |    | offsets    v      v
- *    %sp-->  +--------------------------------+---------------------------
- * 
+ *    %sp--&gt;  +--------------------------------+---------------------------
+ *
  * </pre>
- * 
+ *
  * The spill slot area also includes stack allocated memory blocks (ALLOCA blocks). The size of such
  * a block may be greater than the size of a normal spill slot or the word size.
  * <p>
--- a/graal/com.oracle.graal.lir.sparc/src/com/oracle/graal/lir/sparc/SPARCFrameMap.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.lir.sparc/src/com/oracle/graal/lir/sparc/SPARCFrameMap.java	Mon Mar 31 20:51:09 2014 +0200
@@ -28,12 +28,12 @@
 
 /**
  * SPARC specific frame map.
- * 
+ *
  * This is the format of a SPARC stack frame:
- * 
+ *
  * <pre>
  *   Base       Contents
- * 
+ *
  *            :                                :  -----
  *   caller   | incoming overflow argument n   |    ^
  *   frame    :     ...                        :    | positive
@@ -54,10 +54,10 @@
  *            |                                |    |            |      |
  *            : callee save area               :    |            |      |
  *            |                                |    |            v      v
- *    %sp-->  +--------------------------------+---------------------------
- * 
+ *    %sp--&gt;  +--------------------------------+---------------------------
+ *
  * </pre>
- * 
+ *
  * The spill slot area also includes stack allocated memory blocks (ALLOCA blocks). The size of such
  * a block may be greater than the size of a normal spill slot or the word size.
  * <p>
--- a/graal/com.oracle.graal.lir/src/com/oracle/graal/lir/EdgeMoveOptimizer.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.lir/src/com/oracle/graal/lir/EdgeMoveOptimizer.java	Mon Mar 31 20:51:09 2014 +0200
@@ -29,21 +29,21 @@
 
 /**
  * This class optimizes moves, particularly those that result from eliminating SSA form.
- * 
+ *
  * When a block has more than one predecessor, and all predecessors end with the
  * {@linkplain #same(LIRInstruction, LIRInstruction) same} sequence of {@linkplain MoveOp move}
  * instructions, then these sequences can be replaced with a single copy of the sequence at the
  * beginning of the block.
- * 
+ *
  * Similarly, when a block has more than one successor, then same sequences of moves at the
  * beginning of the successors can be placed once at the end of the block. But because the moves
  * must be inserted before all branch instructions, this works only when there is exactly one
  * conditional branch at the end of the block (because the moves must be inserted before all
  * branches, but after all compares).
- * 
- * This optimization affects all kind of moves (reg->reg, reg->stack and stack->reg). Because this
- * optimization works best when a block contains only a few moves, it has a huge impact on the
- * number of blocks that are totally empty.
+ *
+ * This optimization affects all kind of moves (reg-&gt;reg, reg-&gt;stack and stack-&gt;reg).
+ * Because this optimization works best when a block contains only a few moves, it has a huge impact
+ * on the number of blocks that are totally empty.
  */
 public final class EdgeMoveOptimizer {
 
@@ -79,7 +79,7 @@
      * Determines if two operations are both {@linkplain MoveOp moves} that have the same
      * {@linkplain MoveOp#getInput() source} and {@linkplain MoveOp#getResult() destination}
      * operands.
-     * 
+     *
      * @param op1 the first instruction to compare
      * @param op2 the second instruction to compare
      * @return {@code true} if {@code op1} and {@code op2} are the same by the above algorithm
--- a/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/ConstantNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/ConstantNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -103,7 +103,7 @@
     }
 
     /**
-     * Replaces this node at its usages with another node. If {@value #ConstantNodeRecordsUsages} is
+     * Replaces this node at its usages with another node. If {@link #ConstantNodeRecordsUsages} is
      * false, this is an expensive operation that should only be used in test/verification/AOT code.
      */
     public void replace(StructuredGraph graph, Node replacement) {
--- a/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/FrameState.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/FrameState.java	Mon Mar 31 20:51:09 2014 +0200
@@ -131,7 +131,7 @@
     /**
      * Simple constructor used to create marker FrameStates.
      * 
-     * @param bci marker bci, needs to be < 0
+     * @param bci marker bci, needs to be &lt; 0
      */
     public FrameState(int bci) {
         this(null, bci, Collections.<ValueNode> emptyList(), 0, 0, false, false, Collections.<MonitorIdNode> emptyList(), Collections.<EscapeObjectState> emptyList());
--- a/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/BinaryNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/BinaryNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -155,7 +155,7 @@
      * criterion: {@code (a + 2) + 1 => a + (1 + 2)}
      * <p>
      * This method accepts only {@linkplain #canTryReassociate(BinaryNode) reassociable} operations
-     * such as +, -, *, &, | and ^
+     * such as +, -, *, &amp;, | and ^
      */
     public static BinaryNode reassociate(BinaryNode node, NodePredicate criterion) {
         assert canTryReassociate(node);
--- a/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/NormalizeCompareNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/calc/NormalizeCompareNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -28,8 +28,9 @@
 import com.oracle.graal.nodes.type.*;
 
 /**
- * Returns -1, 0, or 1 if either x < y, x == y, or x > y. If the comparison is undecided (one of the
- * inputs is NaN), the result is 1 if isUnorderedLess is false and -1 if isUnorderedLess is true.
+ * Returns -1, 0, or 1 if either x &lt; y, x == y, or x &gt; y. If the comparison is undecided (one
+ * of the inputs is NaN), the result is 1 if isUnorderedLess is false and -1 if isUnorderedLess is
+ * true.
  */
 public final class NormalizeCompareNode extends BinaryNode implements Lowerable {
 
@@ -37,7 +38,7 @@
 
     /**
      * Creates a new compare operation.
-     * 
+     *
      * @param x the first input
      * @param y the second input
      * @param isUnorderedLess true when an unordered floating point comparison is interpreted as
--- a/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/extended/BranchProbabilityNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.nodes/src/com/oracle/graal/nodes/extended/BranchProbabilityNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -110,11 +110,12 @@
     /**
      * This intrinsic should only be used for the condition of an if statement. The parameter
      * condition should also only denote a simple condition and not a combined condition involving
-     * && or || operators. It injects the probability of the condition into the if statement.
-     * 
+     * &amp;&amp; or || operators. It injects the probability of the condition into the if
+     * statement.
+     *
      * @param probability the probability that the given condition is true as a double value between
      *            0.0 and 1.0.
-     * @param condition the simple condition without any && or || operators
+     * @param condition the simple condition without any &amp;&amp; or || operators
      * @return the condition
      */
     @NodeIntrinsic
--- a/graal/com.oracle.graal.options/src/com/oracle/graal/options/OptionValue.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.options/src/com/oracle/graal/options/OptionValue.java	Mon Mar 31 20:51:09 2014 +0200
@@ -67,7 +67,7 @@
      * used:
      *
      * <pre>
-     * Map<OptionValue, Object> overrides = new HashMap<>();
+     * Map&lt;OptionValue, Object&gt; overrides = new HashMap&lt;&gt;();
      * overrides.put(myOption1, myValue1);
      * overrides.put(myOption2, myValue2);
      * try (OverrideScope s = OptionValue.override(overrides) {
--- a/graal/com.oracle.graal.phases.common/src/com/oracle/graal/phases/common/InliningUtil.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.phases.common/src/com/oracle/graal/phases/common/InliningUtil.java	Mon Mar 31 20:51:09 2014 +0200
@@ -508,7 +508,7 @@
     }
 
     /**
-     * Polymorphic inlining of m methods with n type checks (n >= m) in case that the profiling
+     * Polymorphic inlining of m methods with n type checks (n &ge; m) in case that the profiling
      * information suggests a reasonable amount of different receiver types and different methods.
      * If an unknown type is encountered a deoptimization is triggered.
      */
@@ -1040,7 +1040,7 @@
 
     /**
      * Determines if inlining is possible at the given invoke node.
-     * 
+     *
      * @param invoke the invoke that should be inlined
      * @return an instance of InlineInfo, or null if no inlining is possible at the given invoke
      */
@@ -1304,7 +1304,7 @@
 
     /**
      * Performs an actual inlining, thereby replacing the given invoke with the given inlineGraph.
-     * 
+     *
      * @param invoke the invoke that will be replaced
      * @param inlineGraph the graph that the invoke will be replaced with
      * @param receiverNullCheck true if a null check needs to be generated for non-static inlinings,
--- a/graal/com.oracle.graal.phases/src/com/oracle/graal/phases/schedule/SchedulePhase.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.phases/src/com/oracle/graal/phases/schedule/SchedulePhase.java	Mon Mar 31 20:51:09 2014 +0200
@@ -465,11 +465,11 @@
      *
      * <pre>
      *    U      upperbound block, defined by last access location of the floating read
-     *    &#9650;
+     *    &and;
      *    E      earliest block
-     *    &#9650;
+     *    &and;
      *    O      optimal block, first block that contains a kill of the read's location
-     *    &#9650;
+     *    &and;
      *    L      latest block
      * </pre>
      *
--- a/graal/com.oracle.graal.printer/src/com/oracle/graal/printer/HexCodeFile.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.printer/src/com/oracle/graal/printer/HexCodeFile.java	Mon Mar 31 20:51:09 2014 +0200
@@ -34,9 +34,9 @@
 /**
  * A HexCodeFile is a textual format for representing a chunk of machine code along with extra
  * information that can be used to enhance a disassembly of the code.
- * 
+ *
  * A pseudo grammar for a HexCodeFile is given below.
- * 
+ *
  * <pre>
  *     HexCodeFile ::= Platform Delim HexCode Delim (OptionalSection Delim)*
  * 
@@ -56,32 +56,32 @@
  * 
  *     Position, EntrySize, Low, High, NPairs KeySize OffsetSize ::= int
  * 
- *     Delim := "<||@"
+ *     Delim := "&lt;||@"
  * </pre>
- * 
+ *
  * There must be exactly one HexCode and Platform part in a HexCodeFile. The length of HexDigits
  * must be even as each pair of digits represents a single byte.
  * <p>
  * Below is an example of a valid Code input:
- * 
+ *
  * <pre>
- * 
- *  Platform AMD64 64  <||@
- *  HexCode 0 e8000000009090904883ec084889842410d0ffff48893c24e800000000488b3c24488bf0e8000000004883c408c3  <||@
+ *
+ *  Platform AMD64 64  &lt;||@
+ *  HexCode 0 e8000000009090904883ec084889842410d0ffff48893c24e800000000488b3c24488bf0e8000000004883c408c3  &lt;||@
  *  Comment 24 frame-ref-map: +0 {0}
  *  at java.lang.String.toLowerCase(String.java:2496) [bci: 1]
  *              |0
  *     locals:  |stack:0:a
  *     stack:   |stack:0:a
- *    <||@
- *  OperandComment 24 {java.util.Locale.getDefault()}  <||@
+ *    &lt;||@
+ *  OperandComment 24 {java.util.Locale.getDefault()}  &lt;||@
  *  Comment 36 frame-ref-map: +0 {0}
  *  at java.lang.String.toLowerCase(String.java:2496) [bci: 4]
  *              |0
  *     locals:  |stack:0:a
- *    <||@
- *  OperandComment 36 {java.lang.String.toLowerCase(Locale)}  <||@
- * 
+ *    &lt;||@
+ *  OperandComment 36 {java.lang.String.toLowerCase(Locale)}  lt;||@
+ *
  * </pre>
  */
 public class HexCodeFile {
@@ -209,7 +209,7 @@
 
     /**
      * Sets an operand comment for a given position.
-     * 
+     *
      * @return the previous operand comment for {@code pos}
      */
     public String addOperandComment(int pos, String comment) {
--- a/graal/com.oracle.graal.replacements/src/com/oracle/graal/replacements/SnippetTemplate.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.replacements/src/com/oracle/graal/replacements/SnippetTemplate.java	Mon Mar 31 20:51:09 2014 +0200
@@ -994,7 +994,7 @@
      * @param replacee the node that will be replaced
      * @param replacer object that replaces the usages of {@code replacee}
      * @param args the arguments to be bound to the flattened positional parameters of the snippet
-     * @return the map of duplicated nodes (original -> duplicate)
+     * @return the map of duplicated nodes (original -&gt; duplicate)
      */
     public Map<Node, Node> instantiate(MetaAccessProvider metaAccess, FixedNode replacee, UsageReplacer replacer, Arguments args) {
         assert checkSnippetKills(replacee);
--- a/graal/com.oracle.truffle.api.dsl.test/src/com/oracle/truffle/api/dsl/test/package-info.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api.dsl.test/src/com/oracle/truffle/api/dsl/test/package-info.java	Mon Mar 31 20:51:09 2014 +0200
@@ -42,7 +42,6 @@
  * <ul>
  * <li>What do I need to get started? {@link com.oracle.truffle.api.dsl.test.TypeSystemTest}</li>
  * </ul>
- * </p>
  *
  */
 package com.oracle.truffle.api.dsl.test;
--- a/graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeCheck.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeCheck.java	Mon Mar 31 20:51:09 2014 +0200
@@ -35,45 +35,43 @@
  * {@link TypeSystem}. You can define multiple overloaded {@link TypeCheck} methods for the same
  * type. This can be used to reduce the boxing overhead in type conversions.
  * </p>
- * 
+ *
  * <p>
  * By default the system generates type checks for all types in the parent {@link TypeSystem} which
  * look like the follows:
- * 
+ *
  * <pre>
  * {@literal @}TypeCheck
  * boolean is${typeName}(Object value) {
  *         return value instanceof ${typeName};
  * }
  * </pre>
- * 
- * </p>
- * 
+ *
  * <b>Example:</b>
  * <p>
  * A type check for BigInteger with one overloaded optimized variant to reduce boxing.
  * </p>
- * 
+ *
  * <pre>
- * 
- * 
+ *
+ *
  * {@literal @}TypeSystem(types = {int.class, BigInteger.class, String.class}, nodeBaseClass = TypedNode.class)
  * public abstract class Types {
- * 
+ *
  *     {@literal @}TypeCheck
  *     public boolean isBigInteger(Object value) {
  *         return value instanceof Integer || value instanceof BigInteger;
  *     }
- * 
+ *
  *     {@literal @}TypeCheck
  *     public boolean isBigInteger(int value) {
  *         return true;
  *     }
- * 
+ *
  * }
  * </pre>
- * 
- * 
+ *
+ *
  */
 @Retention(RetentionPolicy.CLASS)
 @Target({ElementType.METHOD})
--- a/graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeSystem.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api.dsl/src/com/oracle/truffle/api/dsl/TypeSystem.java	Mon Mar 31 20:51:09 2014 +0200
@@ -37,7 +37,7 @@
  * concrete type is found first when searching the list sequentially for the type of a given generic
  * value.
  * </p>
- * 
+ *
  * <p>
  * Each {@link #value()} is represented as a java type. A type can specify two annotations:
  * {@link TypeCheck} and {@link TypeCast}. The {@link TypeCheck} checks whether a given generic
@@ -51,31 +51,30 @@
  * accept also {@link Integer} values, implicitly converting them to {@link Double} . This example
  * points out how we express implicit type conversions.
  * </p>
- * 
+ *
  * <p>
  * <b>Example:</b> The {@link TypeSystem} contains the types {@link Boolean}, {@link Integer}, and
  * {@link Double}. The type {@link Object} is always used implicitly as the generic type represent
  * all values.
- * 
+ *
  * <pre>
- * 
+ *
  * {@literal @}TypeSystem(types = {boolean.class, int.class, double.class})
  * public abstract class ExampleTypeSystem {
- * 
+ *
  *     {@literal @}TypeCheck
  *     public boolean isInteger(Object value) {
  *         return value instanceof Integer || value instanceof Double;
  *     }
- * 
+ *
  *     {@literal @}TypeCast
  *     public double asInteger(Object value) {
  *         return ((Number)value).doubleValue();
  *     }
  * }
  * </pre>
- * 
- * </p>
- * 
+ *
+ *
  * @see TypeCast
  * @see TypeCheck
  */
--- a/graal/com.oracle.truffle.api.test/src/com/oracle/truffle/api/test/package-info.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api.test/src/com/oracle/truffle/api/test/package-info.java	Mon Mar 31 20:51:09 2014 +0200
@@ -46,7 +46,6 @@
  * <li>How to use type specialization and speculation for node return values? {@link com.oracle.truffle.api.test.ReturnTypeSpecializationTest}</li>
  * </ul>
  *
- * </p>
  *
  */
 package com.oracle.truffle.api.test;
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/CompilerDirectives.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/CompilerDirectives.java	Mon Mar 31 20:51:09 2014 +0200
@@ -114,7 +114,7 @@
      * be greater than b is 90%):
      *
      * <code>
-     * if (injectBranchProbability(0.9, a > b)) {
+     * if (injectBranchProbability(0.9, a &gt; b)) {
      *    // ...
      * }
      * </code>
@@ -124,7 +124,7 @@
      * 10%):
      *
      * <code>
-     * if (injectBranchProbability(0.9, a > b) && injectBranchProbability(0.1, a == 0)) {
+     * if (injectBranchProbability(0.9, a &gt; b) &amp;&amp; injectBranchProbability(0.1, a == 0)) {
      *    // ...
      * }
      * </code>
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/debug/DefaultDebugManager.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/debug/DefaultDebugManager.java	Mon Mar 31 20:51:09 2014 +0200
@@ -46,12 +46,12 @@
     private Source beingLoaded = null;
 
     /**
-     * Map: SourceSection ==> probe chain associated with that source section in an AST.
+     * Map: SourceSection ==&gt; probe chain associated with that source section in an AST.
      */
     private final Map<SourceSection, ProbeChain> srcToProbeChain = new HashMap<>();
 
     /**
-     * Map: Source lines ==> probe chains associated with source sections starting on the line.
+     * Map: Source lines ==&gt; probe chains associated with source sections starting on the line.
      */
     private final Map<SourceLineLocation, Set<ProbeChain>> lineToProbeChains = new HashMap<>();
 
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/SLMain.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/SLMain.java	Mon Mar 31 20:51:09 2014 +0200
@@ -48,7 +48,7 @@
  * available for the types encountered at run time, a type error is reported and execution is
  * stopped. For example, {@code 4 - "2"} results in a type error because subtraction is only defined
  * for numbers.
- * 
+ *
  * <p>
  * <b>Types:</b>
  * <ul>
@@ -64,7 +64,7 @@
  * </ul>
  * The class {@link SLTypes} lists these types for the Truffle DSL, i.e., for type-specialized
  * operations that are specified using Truffle DSL annotations.
- * 
+ *
  * <p>
  * <b>Language concepts:</b>
  * <ul>
@@ -72,8 +72,8 @@
  * and {@link SLFunctionLiteralNode functions}.
  * <li>Basic arithmetic, logical, and comparison operations: {@link SLAddNode +}, {@link SLSubNode
  * -}, {@link SLMulNode *}, {@link SLDivNode /}, {@link SLLogicalAndNode logical and},
- * {@link SLLogicalOrNode logical or}, {@link SLEqualNode ==}, !=, {@link SLLessThanNode <},
- * {@link SLLessOrEqualNode <=}, >, >=.
+ * {@link SLLogicalOrNode logical or}, {@link SLEqualNode ==}, !=, {@link SLLessThanNode &lt;},
+ * {@link SLLessOrEqualNode &le;}, &gt;, &ge;.
  * <li>Local variables: local variables must be defined (via a {@link SLWriteLocalVariableNode
  * write}) before they can be used (by a {@link SLReadLocalVariableNode read}). Local variables are
  * not visible outside of the block where they were first defined.
@@ -83,7 +83,7 @@
  * <li>Function calls: {@link SLInvokeNode invocations} are efficiently implemented with
  * {@link SLAbstractDispatchNode polymorphic inline caches}.
  * </ul>
- * 
+ *
  * <p>
  * <b>Syntax and parsing:</b><br>
  * The syntax is described as an attributed grammar. The {@link Parser} and {@link Scanner} are
@@ -93,7 +93,7 @@
  * calls to the {@link SLNodeFactory} that performs the actual node creation. All functions found in
  * the SL source are added to the {@link SLFunctionRegistry}, which is accessible from the
  * {@link SLContext}.
- * 
+ *
  * <p>
  * <b>Builtin functions:</b><br>
  * Library functions that are available to every SL source without prior definition are called
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/SLExpressionNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/SLExpressionNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -31,8 +31,8 @@
 
 /**
  * Base class for all SL nodes that produce a value and therefore benefit from type specialization.
- * The annotation {@Link TypeSystemReference} specifies the SL types. Specifying it here
- * defines the type system for all subclasses.
+ * The annotation {@link TypeSystemReference} specifies the SL types. Specifying it here defines the
+ * type system for all subclasses.
  */
 @TypeSystemReference(SLTypes.class)
 public abstract class SLExpressionNode extends SLStatementNode {
@@ -44,8 +44,8 @@
     public abstract Object executeGeneric(VirtualFrame frame);
 
     /**
-     * When we use an expression at places where a {@SLStatmentNode statement} is
-     * already sufficient, the return value is just discarded.
+     * When we use an expression at places where a {@link SLStatementNode statement} is already
+     * sufficient, the return value is just discarded.
      */
     @Override
     public void executeVoid(VirtualFrame frame) {
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -38,10 +38,10 @@
      */
     @Child private SLExpressionNode conditionNode;
 
-    /** Statement (or {@SLBlockNode block}) executed when the condition is true. */
+    /** Statement (or {@link SLBlockNode block}) executed when the condition is true. */
     @Child private SLStatementNode thenPartNode;
 
-    /** Statement (or {@SLBlockNode block}) executed when the condition is false. */
+    /** Statement (or {@link SLBlockNode block}) executed when the condition is false. */
     @Child private SLStatementNode elsePartNode;
 
     /**
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLWhileNode.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLWhileNode.java	Mon Mar 31 20:51:09 2014 +0200
@@ -39,7 +39,7 @@
      */
     @Child private SLExpressionNode conditionNode;
 
-    /** Statement (or {@SLBlockNode block}) executed as long as the condition is true. */
+    /** Statement (or {@link SLBlockNode block}) executed as long as the condition is true. */
     @Child private SLStatementNode bodyNode;
 
     /**
--- a/graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotRegisterConfig.java	Mon Mar 31 19:07:49 2014 +0200
+++ b/graal/com.oracle.graal.hotspot.amd64/src/com/oracle/graal/hotspot/amd64/AMD64HotSpotRegisterConfig.java	Mon Mar 31 20:51:09 2014 +0200
@@ -34,6 +34,7 @@
 import com.oracle.graal.graph.*;
 import com.oracle.graal.hotspot.*;
 import com.oracle.graal.hotspot.nodes.type.*;
+import com.oracle.graal.phases.*;
 
 public class AMD64HotSpotRegisterConfig implements RegisterConfig {
 
@@ -43,8 +44,8 @@
 
     /**
      * The same as {@link #allocatable}, except if parameter registers are removed with the
      * {@link #RegisterPressure} option. The caller saved registers always include all parameter
      * registers.
      */
     private final Register[] callerSaved;
 
@@ -43,8 +44,8 @@
     /**
      * The same as {@link #allocatable}, except if parameter registers are removed with the
-     * {@link #RegisterPressure} option. The caller saved registers always include all parameter
-     * registers.
+     * {@link GraalOptions#RegisterPressure} option. The caller saved registers always include all
+     * parameter registers.
      */
     private final Register[] callerSaved;